==> qtkeychain_0.10.0.orig.tar.gz: qtkeychain-0.10.0/translations/qtkeychain_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QKeychain::DeletePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_win.cpp" line="79"/>
        <source>Password entry not found</source>
        <translation type="unfinished">Mot de passe non trouvé</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="83"/>
        <source>Could not decrypt data</source>
        <translation type="unfinished">Impossible de déchiffrer les données</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="546"/>
        <location filename="../keychain_unix.cpp" line="554"/>
        <source>Unknown error</source>
        <translation type="unfinished">Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="572"/>
        <source>Could not open wallet: %1; %2</source>
        <translation type="unfinished">Impossible d'ouvrir le trousseau&nbsp;: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="120"/>
        <source>Password not found</source>
        <translation type="unfinished">Mot de passe non trouvé</translation>
    </message>
</context>
<context>
    <name>QKeychain::JobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="263"/>
        <source>Unknown error</source>
        <translation type="unfinished">Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="507"/>
        <source>Access to keychain denied</source>
        <translation type="unfinished">Accès au trousseau refusé</translation>
    </message>
</context>
<context>
    <name>QKeychain::PlainTextStore</name>
    <message>
        <location filename="../plaintextstore.cpp" line="65"/>
        <source>Could not store data in settings: access error</source>
        <translation type="unfinished">Impossible de stocker les paramètres&nbsp;: Erreur d'accès</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="67"/>
        <source>Could not store data in settings: format error</source>
        <translation type="unfinished">Impossible de stocker les paramètres&nbsp;: Erreur de format</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="85"/>
        <source>Could not delete data from settings: access error</source>
        <translation type="unfinished">Impossible de supprimer des paramètres&nbsp;: Erreur d'accès</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="87"/>
        <source>Could not delete data from settings: format error</source>
        <translation type="unfinished">Impossible de supprimer des paramètres&nbsp;: Erreur de format</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="104"/>
        <source>Entry not found</source>
        <translation type="unfinished">Entrée non trouvée</translation>
    </message>
</context>
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="185"/>
        <location filename="../keychain_unix.cpp" line="195"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="176"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished">D-Bus non disponible</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="284"/>
        <source>No keychain service available</source>
        <translation>Aucun service de trousseau disponible</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="286"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Impossible d'ouvrir le trousseau&nbsp;: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="331"/>
        <source>Access to keychain denied</source>
        <translation>Accès au trousseau refusé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="352"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Impossible de déterminer le type de données&nbsp;: %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="370"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation type="unfinished">Type d'entrée non supporté &#171;Map&#187;</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="373"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation type="unfinished">Type de trousseau inconnu &#171;%1&#187;</translation>
    </message>
    <message>
        <source>Could not read password: %1; %2</source>
        <translation type="vanished">Impossible de lire le mot de passe&nbsp;: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="75"/>
        <location filename="../keychain_haiku.cpp" line="41"/>
        <source>Password not found</source>
        <translation>Mot de passe non trouvé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="361"/>
        <source>Entry not found</source>
        <translation>Entrée non trouvée</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="32"/>
        <source>Password entry not found</source>
        <translation type="unfinished">Entrée non trouvée</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="36"/>
        <location filename="../keychain_win.cpp" line="114"/>
        <source>Could not decrypt data</source>
        <translation>Impossible de déchiffrer les données</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="423"/>
        <location filename="../keychain_unix.cpp" line="450"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="413"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished">D-Bus non disponible</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="466"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Impossible d'ouvrir le trousseau&nbsp;: %1; %2</translation>
    </message>
    <message>
        <source>Access to keychain denied</source>
        <translation type="vanished">Accès au trousseau refusé</translation>
    </message>
    <message>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation type="vanished">Impossible de supprimer des données chiffrées dans les paramètres&nbsp;: Erreur d'accès</translation>
    </message>
    <message>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation type="vanished">Impossible de supprimer des données chiffrées dans les paramètres&nbsp;: Erreur de format</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <location filename="../keychain_win.cpp" line="137"/>
        <source>Encryption failed</source>
        <translation>Le chiffrement a échoué</translation>
    </message>
    <message>
        <source>Could not store encrypted data in settings: access error</source>
        <translation type="vanished">Impossible de stocker des données chiffrées dans les paramètres&nbsp;: Erreur d'accès</translation>
    </message>
    <message>
        <source>Could not store encrypted data in settings: format error</source>
        <translation type="vanished">Impossible de stocker des données chiffrées dans les paramètres&nbsp;: Erreur de format</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="88"/>
        <source>Password not found</source>
        <translation type="unfinished">Mot de passe non trouvé</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_unix.cpp" line="223"/>
        <source>Access to keychain denied</source>
        <translation>Accès au trousseau refusé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="225"/>
        <source>No keyring daemon</source>
        <translation>Aucun démon de trousseau</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="227"/>
        <source>Already unlocked</source>
        <translation>Déjà déverrouillé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="229"/>
        <source>No such keyring</source>
        <translation>Trousseau non trouvé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="231"/>
        <source>Bad arguments</source>
        <translation>Mauvais arguments</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="233"/>
        <source>I/O error</source>
        <translation>Erreur d'E/S</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="235"/>
        <source>Cancelled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="237"/>
        <source>Keyring already exists</source>
        <translation>Trousseau déjà existant</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="239"/>
        <source>No match</source>
        <translation>Aucune correspondance</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="244"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <source>OS X Keychain error (OSStatus %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="32"/>
        <source>%1 (OSStatus %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libsecret.cpp" line="120"/>
        <source>Entry not found</source>
        <translation type="unfinished">Entrée non trouvée</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="18"/>
        <source>error 0x%1: %2</source>
        <translation type="unfinished">Erreur 0x%1&nbsp;: %2</translation>
    </message>
</context>
</TS>

==> qtkeychain_0.14.3.orig.tar.gz: qtkeychain-0.14.3/translations/qtkeychain_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QKeychain::DeletePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_win.cpp" line="79"/>
        <source>Password entry not found</source>
        <translation>Mot de passe introuvable</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="83"/>
        <source>Could not decrypt data</source>
        <translation>Impossible de déchiffrer les données</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="546"/>
        <location filename="../keychain_unix.cpp" line="554"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="572"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Impossible d&apos;ouvrir le portefeuille : %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="120"/>
        <source>Password not found</source>
        <translation>Mot de passe introuvable</translation>
    </message>
</context>
<context>
    <name>QKeychain::JobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="263"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="507"/>
        <source>Access to keychain denied</source>
        <translation>Accès au trousseau refusé</translation>
    </message>
</context>
<context>
    <name>QKeychain::PlainTextStore</name>
    <message>
        <location filename="../plaintextstore.cpp" line="65"/>
        <source>Could not store data in settings: access error</source>
        <translation>Impossible de stocker les données dans les paramètres : Erreur d&apos;accès</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="67"/>
        <source>Could not store data in settings: format error</source>
        <translation>Impossible de stocker les données dans les paramètres : Erreur de format</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="85"/>
        <source>Could not delete data from settings: access error</source>
        <translation>Impossible de supprimer les données depuis les paramètres : Erreur d&apos;accès</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="87"/>
        <source>Could not delete data from settings: format error</source>
        <translation>Impossible de supprimer les données depuis les paramètres : Erreur de format</translation>
    </message>
    <message>
        <location filename="../plaintextstore.cpp" line="104"/>
        <source>Entry not found</source>
        <translation>Entrée introuvable</translation>
    </message>
</context>
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="185"/>
        <location filename="../keychain_unix.cpp" line="195"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="176"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus n&apos;est pas en cours d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="284"/>
        <source>No keychain service available</source>
        <translation>Aucun service de trousseau disponible</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="286"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Impossible d&apos;ouvrir le trousseau : %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="331"/>
        <source>Access to keychain denied</source>
        <translation>Accès au trousseau refusé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="352"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Impossible de déterminer le type de données : %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="370"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation>Type d&apos;entrée non supporté &apos;Map&apos;</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="373"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation>Type de trousseau inconnu &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Could not read password: %1; %2</source>
        <translation type="vanished">Impossible de lire le mot de passe : %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="75"/>
        <location filename="../keychain_haiku.cpp" line="41"/>
        <source>Password not found</source>
        <translation>Mot de passe introuvable</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="361"/>
        <source>Entry not found</source>
        <translation>Entrée introuvable</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="32"/>
        <source>Password entry not found</source>
        <translation>Entrée de mot de passe introuvable</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="36"/>
        <location filename="../keychain_win.cpp" line="114"/>
        <source>Could not decrypt data</source>
        <translation>Impossible de déchiffrer les données</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="423"/>
        <location filename="../keychain_unix.cpp" line="450"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="413"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus n&apos;est pas en cours d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="466"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Impossible d&apos;ouvrir le trousseau : %1; %2</translation>
    </message>
    <message>
        <source>Access to keychain denied</source>
        <translation type="vanished">Accès au trousseau refusé</translation>
    </message>
    <message>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation type="vanished">Impossible de supprimer des données chiffrées dans les paramètres : Erreur d&apos;accès</translation>
    </message>
    <message>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation type="vanished">Impossible de supprimer des données chiffrées dans les paramètres : Erreur de format</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <location filename="../keychain_win.cpp" line="137"/>
        <source>Encryption failed</source>
        <translation>Le chiffrement a échoué</translation>
    </message>
    <message>
        <source>Could not store encrypted data in settings: access error</source>
        <translation type="vanished">Impossible de stocker des données chiffrées dans les paramètres : Erreur d&apos;accès</translation>
    </message>
    <message>
        <source>Could not store encrypted data in settings: format error</source>
        <translation type="vanished">Impossible de stocker des données chiffrées dans les paramètres : Erreur de format</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="88"/>
        <source>Password not found</source>
        <translation>Mot de passe introuvable</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_unix.cpp" line="223"/>
        <source>Access to keychain denied</source>
        <translation>Accès au trousseau refusé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="225"/>
        <source>No keyring daemon</source>
        <translation>Aucun démon de trousseau</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="227"/>
        <source>Already unlocked</source>
        <translation>Déjà déverrouillé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="229"/>
        <source>No such keyring</source>
        <translation>Aucun trousseau</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="231"/>
        <source>Bad arguments</source>
        <translation>Mauvais arguments</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="233"/>
        <source>I/O error</source>
        <translation>Erreur d&apos;E/S</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="235"/>
        <source>Cancelled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="237"/>
        <source>Keyring already exists</source>
        <translation>Trousseau déjà existant</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="239"/>
        <source>No match</source>
        <translation>Aucune correspondance</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="244"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <source>OS X Keychain error (OSStatus %1)</source>
        <translation>OS X Keychain error (OSStatus %1)</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="32"/>
        <source>%1 (OSStatus %2)</source>
        <translation>%1 (OSStatus %2)</translation>
    </message>
    <message>
        <location filename="../libsecret.cpp" line="120"/>
        <source>Entry not found</source>
        <translation>Entrée introuvable</translation>
    </message>
    <message>
        <location filename="../keychain_haiku.cpp" line="18"/>
        <source>error 0x%1: %2</source>
        <translation>Erreur 0x%1 : %2</translation>
    </message>
</context>
</TS>
